class NeopopSdl < Formula
  desc "NeoGeo Pocket emulator"
  homepage "https://nih.at/NeoPop-SDL/"
  url "https://nih.at/NeoPop-SDL/NeoPop-SDL-0.2.tar.bz2", using: :homebrew_curl
  sha256 "2df1b717faab9e7cb597fab834dc80910280d8abf913aa8b0dcfae90f472352e"
  license "GPL-2.0-or-later"
  revision 1

  head do
    url "https://github.com/nih-at/NeoPop-SDL.git", branch: "master"

    depends_on "autoconf" => :build
    depends_on "pkg-config" => :build
    depends_on "ffmpeg"
  end

  # Homepage says: "Development on this project has stopped. It will no longer be updated."
  deprecate! date: "2022-04-02", because: :unmaintained

  # Added automake as a build dependency to update config files for ARM support.
  depends_on "automake" => :build
  depends_on "libpng"
  depends_on "sdl12-compat"
  depends_on "sdl_net"

  def install
    if build.head?
      system "autoreconf", "-i"
    else
      # Workaround for ancient config files not recognizing aarch64 macos.
      %w[config.guess config.sub].each do |fn|
        cp Formula["automake"].share/"automake-#{Formula["automake"].version.major_minor}"/fn, fn
      end
    end
    system "./configure", "--disable-dependency-tracking",
                          "--disable-silent-rules",
                          "--prefix=#{prefix}",
                          "--mandir=#{man}"
    system "make", "install"
  end

  test do
    # Test fails on headless CI: "cannot initialize SDL: No available video device"
    return if ENV["HOMEBREW_GITHUB_ACTIONS"] && OS.linux?

    assert_equal "NeoPop (SDL) v0.71 (SDL-Version #{version})", shell_output("#{bin}/NeoPop-SDL -V").chomp
  end
end
